Received: from makus.postgresql.org (makus.postgresql.org [98.129.198.125]) by mail.postgresql.org (Postfix) with ESMTP id A754D13FA3D6 for ; Mon, 18 Jun 2012 11:58:40 -0300 (ADT) Received: from gwmta.wicourts.gov ([165.219.244.99] helo=gw.wicourts.gov) by makus.postgresql.org with esmtp (Exim 4.72) (envelope-from ) id 1SgdPb-0003L9-P2 for pgsql-performance@postgresql.org; Mon, 18 Jun 2012 14:58:40 +0000 Received: from Courts-MTA by gw.wicourts.gov with Novell_GroupWise; Mon, 18 Jun 2012 09:58:26 -0500 Message-Id: <4FDEFBC002000025000485EB@gw.wicourts.gov> X-Mailer: Novell GroupWise Internet Agent 8.0.2 Date: Mon, 18 Jun 2012 09:58:24 -0500 From: "Kevin Grittner" To: ,"Tom Lane" Cc: Subject: Re: correlated exists with join is slow. References: <9674.1340031155@sss.pgh.pa.us> In-Reply-To: <9674.1340031155@sss.pgh.pa.us> Mime-Version: 1.0 Content-Type: text/plain; charset=US-ASCII Content-Transfer-Encoding: 7bit Content-Disposition: inline X-Pg-Spam-Score: -4.2 (----) X-Archive-Number: 201206/97 X-Sequence-Number: 47123 Tom Lane wrote: > 9.2 will make this all better. These are exactly the type of case > where you need the "parameterized path" stuff. Yeah, with HEAD on my workstation all of these queries run in less than 0.1 ms. On older versions, I'm seeing times like 100 ms to 150 ms for the slow cases. So in this case, parameterized paths allow an improvement of more than three orders of magnitude. :-) -Kevin